.. _install:

Installing Aesara
=================

Supported platforms:

.. toctree::
  :maxdepth: 1

  install_ubuntu
  install_macos
  install_windows
  install_centos6

To update your current installation see :ref:`updating`.
